@@ -1,5 +1,4 @@
 from eda_report import run_from_cli
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     run_from_cli()
